#[non_exhaustive]pub enum AnalysisError {
InvalidConfiguration {
field: &'static str,
reason: String,
},
InvalidFilter {
field: &'static str,
reason: String,
},
InvalidComponentOutput {
field: &'static str,
reason: String,
},
InputTooLarge {
field: &'static str,
actual: usize,
limit: usize,
},
CapacityExceeded {
resource: &'static str,
limit: usize,
},
InvalidIdentifier {
kind: &'static str,
name: String,
reason: &'static str,
},
InvalidSeverity {
severity: u8,
},
DuplicateName {
kind: &'static str,
name: String,
},
NotFound {
kind: &'static str,
name: String,
},
InvalidRegex {
context: &'static str,
reason: &'static str,
},
}Expand description
Errors returned by validation, analysis configuration, and bounded tracking.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
InvalidConfiguration
A tracker or analyzer configuration value is invalid.
Fields
InvalidFilter
A statistics filter is malformed or internally contradictory.
Fields
InvalidComponentOutput
A custom analyzer or categorizer returned data outside API invariants.
Fields
InputTooLarge
A caller-provided field exceeds its configured UTF-8 byte limit.
Fields
CapacityExceeded
Adding a new retained item would exceed a configured collection limit.
Fields
InvalidIdentifier
A pattern, rule, or category identifier is invalid.
Fields
InvalidSeverity
Suspicious indicator severity lies outside the documented 0-10 range.
DuplicateName
A named pattern or category rule already exists.
NotFound
A named pattern or category rule could not be found.
InvalidRegex
A regular expression could not be compiled.