AnalysisError

Enum AnalysisError 

#[non_exhaustive]
pub enum AnalysisError { InvalidConfiguration { field: &'static str, reason: String, }, InvalidFilter { field: &'static str, reason: String, }, InvalidComponentOutput { field: &'static str, reason: String, }, InputTooLarge { field: &'static str, actual: usize, limit: usize, }, CapacityExceeded { resource: &'static str, limit: usize, }, InvalidIdentifier { kind: &'static str, name: String, reason: &'static str, }, InvalidSeverity { severity: u8, }, DuplicateName { kind: &'static str, name: String, }, NotFound { kind: &'static str, name: String, }, InvalidRegex { context: &'static str, reason: &'static str, }, }
Errors returned by validation, analysis configuration, and bounded tracking.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


InvalidConfiguration

A tracker or analyzer configuration value is invalid.

Fields

field: &'static str

Configuration field that failed validation.

reason: String

Human-readable validation failure.



InvalidFilter

A statistics filter is malformed or internally contradictory.

Fields

field: &'static str

Filter field that failed validation.

reason: String

Human-readable validation failure.



InvalidComponentOutput

A custom analyzer or categorizer returned data outside API invariants.

Fields

field: &'static str

Component output field that failed validation.

reason: String

Human-readable validation failure.



InputTooLarge

A caller-provided field exceeds its configured UTF-8 byte limit.

Fields

field: &'static str

Name of the oversized input field.

actual: usize

Actual UTF-8 byte length.

limit: usize

Configured UTF-8 byte limit.



CapacityExceeded

Adding a new retained item would exceed a configured collection limit.

Fields

resource: &'static str

Bounded resource that reached capacity.

limit: usize

Configured maximum number of items.



InvalidIdentifier

A pattern, rule, or category identifier is invalid.

Fields

kind: &'static str

Kind of identifier being validated.

name: String

Invalid identifier value.

reason: &'static str

Human-readable validation failure.



InvalidSeverity

Suspicious indicator severity lies outside the documented 0-10 range.

Fields

severity: u8

Invalid severity value.



DuplicateName

A named pattern or category rule already exists.

Fields

kind: &'static str

Kind of named object.

name: String

Duplicate name.



NotFound

A named pattern or category rule could not be found.

Fields

kind: &'static str

Kind of named object.

name: String

Missing name.



InvalidRegex

A regular expression could not be compiled.

Fields

context: &'static str

Static description of the pattern or filter being compiled.

reason: &'static str

Sanitized failure class that never contains the expression source.